<template>
  <div class="card-item-main">
    <gree-block class="gree-example-child-radio-3-2">
      <gree-grid :border="false">
        <gree-radio-group v-model="dazzlingMod">
          <gree-radio-box :disabled="item.disabled" :name="item.name" v-for="(item, index) in dazzlingList" :key="index">
            <gree-grid-item :icon="item.icon" :text="item.text" />
          </gree-radio-box>
        </gree-radio-group>
      </gree-grid>
    </gree-block>
  </div>
</template>

<script>
import { RadioBox, RadioGroup, Block, Icon, Grid, GridItem } from 'gree-ui';
import { mapMutations, mapState, mapActions } from 'vuex';
import { types } from '@/store/types';

export default {
  name: 'DazzlingCard',
  components: {
    [Icon.name]: Icon,
    [Grid.name]: Grid,
    [Block.name]: Block,
    [RadioBox.name]: RadioBox,
    [GridItem.name]: GridItem,
    [RadioGroup.name]: RadioGroup
  },
  data() {
    return {
      isShowdescribe: true
    };
  },
  computed: {
    ...mapState('control', {
      Pow: state => state.dataObject.Pow,
      Mod: state => state.dataObject.Mod,
      Dazzling: state => state.dataObject.Dazzling
    }),
    dazzlingList() {
      let result = [
        { name: 1, icon: 'dazzling', text: '炫光模式', disabled: Boolean(!this.Dazzling) },
        { name: 2, icon: 'flowing-light', text: '流光模式', disabled: Boolean(!this.Dazzling) },
        { name: 3, icon: 'light', text: '小夜灯模式', disabled: Boolean(!this.Dazzling) }
      ];
      return result;
    },
    dazzlingMod: {
      get: function() {
        const valueArr = [0, 1, 9, 10];
        return valueArr.indexOf(this.Dazzling) || 0;
      },
      set: function(v) {
        this.onClickCard(v);
      }
    }
  },
  methods: {
    ...mapMutations('control', {
      setDataObject: 'SET_DATA_OBJECT'
    }),
    ...mapActions({
      sendData: types.SEND_DATA,
      sendCtrl: types.SEND_CTRL
    }),
    onClickCard(v) {
      const valueArr = [1, 9, 10];
      this.sendData({
        Dazzling: valueArr[v - 1],
        StHt: 0
      });
    }
  }
};
</script>

<style lang="scss">
.card-item-main {
  .gree-example-child-radio-3-2 {
    margin: 0;
    padding-left: 0;
    padding-right: 0;
    padding-bottom: 20px;
    .gree-grid {
      justify-content: center;
      .gree-check-base-box {
        padding: 0;
        margin: 0 13px;
        border: none;
        width: 300px;
        height: 220px;
        background: rgba(152, 152, 152, 0.1);
        border-radius: 26px;
        box-shadow: 0px 3px 24px 0px rgba(64, 70, 87, 0.03);
        &.is-disabled {
          opacity: 0.3;
        }
        .gree-icon {
          color: #404657;
        }
        .gree-grid-item__text {
          font-size: 38px;
        }
        &.is-checked {
          &:nth-child(1) {
            .gree-icon {
              color: transparent;
            }
            background-image: url('~@/assets/img/functionBtn/Dazzling/Dazzle_light.png');
            background-size: 100%;
          }
          &:nth-child(2) {
            .gree-icon {
              color: transparent;
            }
            background-image: url('~@/assets/img/functionBtn/Dazzling/Flow_light.png');
            background-size: 100%;
          }
          &:nth-child(3) {
            .gree-icon {
              color: transparent;
            }
            background-image: url('~@/assets/img/functionBtn/Dazzling/Night_light.png');
            background-size: 100%;
          }
          .gree-icon.icon-font,
          .gree-grid-item__text {
            color: #fff;
          }
        }
      }
    }
  }
}
</style>
